@@ -88,11 +88,7 @@ setConstructorS3("AllelicCrosstalkCalibration", function(dataSet=NULL, ..., mode
 
   # Argument 'dataSet':
   if (!is.null(dataSet)) {
-    if (!inherits(dataSet, "AffymetrixCelSet")) {
-      throw("Argument 'dataSet' is not an AffymetrixCelSet object: ", 
-                                                          class(dataSet)[1]);
-    }
-
+    dataSet <- Arguments$getInstanceOf(dataSet, "AffymetrixCelSet");
 
     # Argument 'model':
     model <- match.arg(model);
@@ -180,8 +176,7 @@ setConstructorS3("AllelicCrosstalkCalibration", function(dataSet=NULL, ..., mode
       }
       extraTags <- c(extraTags, subsetToAvg=subsetToAvg);
     } else {
-      subsetToAvg <- Arguments$getIndices(subsetToAvg, 
-                                          range=c(1, nbrOfCells(cdf)));
+      subsetToAvg <- Arguments$getIndices(subsetToAvg, max=nbrOfCells(cdf));
       subsetToAvg <- unique(subsetToAvg);
       subsetToAvg <- sort(subsetToAvg);
     }
@@ -1054,7 +1049,7 @@ setMethodS3("plotBasepair", "AllelicCrosstalkCalibration", function(this, array,
   }
 
   # Argument 'array':
-  array <- Arguments$getIndex(array, length=nbrOfArrays(cs));
+  array <- Arguments$getIndex(array, max=nbrOfArrays(cs));
 
 
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
