@@ -33,9 +33,7 @@ setConstructorS3("FirmaModel", function(rmaPlm=NULL, summaryMethod=c("median", "
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Argument 'rmaPlm':
   if (!is.null(rmaPlm)) {
-    if (!inherits(rmaPlm, "ProbeLevelModel")) {
-      throw("Argument 'rmaPlm' is not a ProbeLevelModel: ", class(rmaPlm)[1]);
-    }
+    rmaPlm <- Arguments$getInstanceOf(rmaPlm, "ProbeLevelModel");
   }
 
   # Argument 'summaryMethod':
@@ -531,7 +529,7 @@ setMethodS3("fit", "FirmaModel", function(this, units="remaining", ..., ram=NULL
   doRemaining <- FALSE;
   if (is.null(units)) {
   } else if (is.numeric(units)) {
-    units <- Arguments$getIndices(units, range=c(1, nbrOfUnits(cdf)));
+    units <- Arguments$getIndices(units, max=nbrOfUnits(cdf));
   } else if (identical(units, "remaining")) {
     doRemaining <- TRUE;
   } else {
