@@ -59,16 +59,13 @@ setConstructorS3("FragmentLengthNormalization", function(dataSet=NULL, ..., targ
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Argument 'dataSet':
   if (!is.null(dataSet)) {
-    if (!inherits(dataSet, "SnpChipEffectSet"))
-      throw("Argument 'dataSet' is not an SnpChipEffectSet object: ", 
-                                                        class(dataSet)[1]);
+    dataSet <- Arguments$getInstanceOf(dataSet, "SnpChipEffectSet");
 
 #    if (dataSet$combineAlleles != TRUE) {
 #      throw("Currently only total copy-number chip effects can be normalized, i.e. 'combineAlleles' must be TRUE");
 #    }
 
-#    if (!inherits(dataSet, "CnChipEffectSet"))
-#      throw("Argument 'dataSet' is not an CnChipEffectSet object: ", class(dataSet)[1]);
+#    dataSet <- Arguments$getInstanceOf(dataSet, "CnChipEffectSet");
 
 #    if (dataSet$mergeStrands != TRUE) {
 #      throw("Currently only non-strands specific copy-number chip effects can be normalized, i.e. 'mergeStrands' must be TRUE");
@@ -105,8 +102,7 @@ setConstructorS3("FragmentLengthNormalization", function(dataSet=NULL, ..., targ
     extraTags <- c(extraTags, subsetToFit=subsetToFit);
   } else {
     cdf <- getCdf(dataSet);
-    subsetToFit <- Arguments$getIndices(subsetToFit, 
-                                        range=c(1, nbrOfUnits(cdf)));
+    subsetToFit <- Arguments$getIndices(subsetToFit, max=nbrOfUnits(cdf));
     subsetToFit <- unique(subsetToFit);
     subsetToFit <- sort(subsetToFit);
   }
